@@ -5,26 +5,25 @@
 
     The application from th web.py tutorial.
 
-    :copyright: Copyright 2007 by Armin Ronacher.
-    :license: BSD.
+    :copyright: 2007 Pallets
+    :license: BSD-3-Clause
 """
-from webpylike import WebPyApp, View, Response
+from .webpylike import Response
+from .webpylike import View
+from .webpylike import WebPyApp
 
 
-urls = (
-    '/',        'index',
-    '/about',   'about'
-)
+urls = ("/", "index", "/about", "about")
 
 
 class index(View):
     def GET(self):
-        return Response('Hello World')
+        return Response("Hello World")
 
 
 class about(View):
     def GET(self):
-        return Response('This is the about page')
+        return Response("This is the about page")
 
 
 app = WebPyApp(urls, globals())
