@@ -16,6 +16,7 @@ import pytest
 import requests
 
 from werkzeug._compat import PY2
+from werkzeug.debug import console
 from werkzeug.debug import DebuggedApplication
 from werkzeug.debug import get_machine_id
 from werkzeug.debug.console import HTMLStringO
@@ -354,3 +355,42 @@ def test_basic(dev_server, crash):
         assert "The debugger caught an exception in your WSGI application" in r.text
     else:
         assert r.text == "hello"
+
+
+def test_console_closure_variables(monkeypatch):
+    # restore the original display hook
+    monkeypatch.setattr(sys, "displayhook", console._displayhook)
+    c = console.Console()
+    c.eval("y = 5")
+    c.eval("x = lambda: y")
+    # strip() is only needed for Python 2 compat
+    ret = c.eval("x()").strip()
+    assert ret == ">>> x()\n5"
+
+
+@pytest.mark.skipif(PY2, reason="Python 2 doesn't have chained exceptions.")
+@pytest.mark.timeout(2)
+def test_chained_exception_cycle():
+    try:
+        try:
+            raise ValueError()
+        except ValueError:
+            raise TypeError()
+    except TypeError as e:
+        # create a cycle and make it available outside the except block
+        e.__context__.__context__ = error = e
+
+    # if cycles aren't broken, this will time out
+    tb = Traceback(TypeError, error, error.__traceback__)
+    assert len(tb.groups) == 2
+
+
+def test_non_hashable_exception():
+    class MutableException(ValueError):
+        __hash__ = None
+
+    try:
+        raise MutableException()
+    except MutableException:
+        # previously crashed: `TypeError: unhashable type 'MutableException'`
+        Traceback(*sys.exc_info())
